pub struct LBFConfig {
pub cde_config: CDEConfig,
pub poly_simpl_tolerance: Option<f32>,
pub narrow_concavity_cutoff: Option<(f32, f32)>,
pub min_item_separation: Option<f32>,
pub prng_seed: Option<u64>,
pub n_samples: usize,
pub ls_frac: f32,
pub svg_draw_options: SvgDrawOptions,
}Expand description
Configuration for the LBF optimizer
Fields
cde_config: CDEConfigConfiguration of the Collision Detection Engine
poly_simpl_tolerance: Option<f32>Max deviation from the original polygon area as a fraction. If undefined, the algorithm will run without simplification
narrow_concavity_cutoff: Option<(f32, f32)>Definition of what is considered a narrow concavity that will be closed
See jagua_rs::geometry::shape_modification::ShapeModifyConfig for more details.
If undefined, the algorithm will run without closing narrow concavities
min_item_separation: Option<f32>Minimum distance between items and other hazards. If undefined, the algorithm will run without this constraint
prng_seed: Option<u64>Seed for the PRNG. If undefined, the algorithm will run in non-deterministic mode using entropy
n_samples: usizeTotal budget of samples per item per layout
ls_frac: f32Fraction of n_samples_per_item used for the local search sampler, the rest is sampled uniformly.
svg_draw_options: SvgDrawOptionsOptional SVG drawing options